@@ -1,14 +1,14 @@
 package Bencher::Scenario::URIEscaping;
 
-our $DATE = '2016-06-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-06-17'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use utf8;
 use warnings;
 
-# we do this so URI::XSEscaoe does not override URI::Escape's functions, because
+# we do this so URI::XSEscape does not override URI::Escape's functions, because
 # obviously we want to test both
 $ENV{PERL_URI_XSESCAPE} = 0;
 
@@ -27,6 +27,11 @@ our $scenario = {
         {fcall_template => 'URI::Escape::XS::uri_escape(<str>)', tags=>['escape']},
         #{fcall_template => 'URI::Escape::XS::uri_escape_utf8(<str>)', tags=>['escape', 'utf8']},
         {fcall_template => 'URI::Escape::XS::uri_unescape(<str>)', tags=>['unescape']},
+
+        {fcall_template => 'URI::Encode::uri_encode(<str>)', tags=>['escape']},
+        {fcall_template => 'URI::Encode::uri_decode(<str>)', tags=>['unescape']},
+        {fcall_template => 'URI::Encode::XS::uri_encode(<str>)', tags=>['escape']},
+        {fcall_template => 'URI::Encode::XS::uri_decode(<str>)', tags=>['unescape']},
     ],
 
     datasets => [
@@ -90,7 +95,7 @@ Bencher::Scenario::URIEscaping - Benchmark URI escaping using various modules
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::URIEscaping (from Perl distribution Bencher-Scenario-URIEscaping), released on 2016-06-16.
+This document describes version 0.003 of Bencher::Scenario::URIEscaping (from Perl distribution Bencher-Scenario-URIEscaping), released on 2016-06-17.
 
 =head1 SYNOPSIS
 
@@ -114,6 +119,10 @@ L<URI::XSEscape> 0.000007
 
 L<URI::Escape::XS> 0.14
 
+L<URI::Encode> 1.1.1
+
+L<URI::Encode::XS> 0.08
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -182,6 +191,38 @@ Function call template:
 
 
 
+=item * URI::Encode::uri_encode (perl_code) [escape]
+
+Function call template:
+
+ URI::Encode::uri_encode(<str>)
+
+
+
+=item * URI::Encode::uri_decode (perl_code) [unescape]
+
+Function call template:
+
+ URI::Encode::uri_decode(<str>)
+
+
+
+=item * URI::Encode::XS::uri_encode (perl_code) [escape]
+
+Function call template:
+
+ URI::Encode::XS::uri_encode(<str>)
+
+
+
+=item * URI::Encode::XS::uri_decode (perl_code) [unescape]
+
+Function call template:
+
+ URI::Encode::XS::uri_decode(<str>)
+
+
+
 =back
 
 =head1 BENCHMARK DATASETS
@@ -209,43 +250,55 @@ Run on: perl: I<< v5.22.1 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 Benchmark with default options (C<< bencher -m URIEscaping >>):
 
  +--------------------------------+-----------+-----------+-----------+------------+---------+---------+
- | participant                    | dataset   | rate (/s) | time (μs) | vs_slowest | errors  | samples |
+ | participant                    | dataset   | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +--------------------------------+-----------+-----------+-----------+------------+---------+---------+
- | URI::Escape::uri_escape_utf8   | ascii53   | 8.05e+04  | 12.4      | 1          | 1.2e-08 | 23      |
- | URI::Escape::uri_escape        | ascii53   | 8.6e+04   | 12        | 1.1        | 1.2e-08 | 26      |
- | URI::Escape::uri_escape_utf8   | utf36     | 9.57e+04  | 10.4      | 1.19       | 3.3e-09 | 20      |
- | URI::Escape::uri_escape_utf8   | ascii66   | 1.14e+05  | 8.81      | 1.41       | 8.8e-09 | 46      |
- | URI::Escape::uri_unescape      | u_ascii53 | 1.2e+05   | 8.7       | 1.4        | 8.7e-09 | 47      |
- | URI::Escape::uri_escape        | ascii66   | 1.22e+05  | 8.21      | 1.51       | 7.5e-09 | 255     |
- | URI::Escape::uri_unescape      | u_ascii66 | 1.8e+05   | 5.57      | 2.23       | 4.4e-09 | 237     |
- | URI::Escape::uri_escape_utf8   | empty     | 9e+05     | 1.1       | 11         | 1.2e-09 | 41      |
- | URI::Escape::uri_escape        | empty     | 1.3e+06   | 0.78      | 16         | 8.3e-10 | 45      |
- | URI::XSEscape::uri_escape_utf8 | ascii66   | 1.3e+06   | 0.76      | 16         | 8.3e-10 | 81      |
- | URI::XSEscape::uri_escape_utf8 | ascii53   | 1.342e+06 | 0.7453    | 16.68      | 4.3e-11 | 20      |
- | URI::Escape::XS::uri_escape    | ascii66   | 1.38e+06  | 0.727     | 17.1       | 3.5e-10 | 28      |
- | URI::Escape::XS::uri_escape    | ascii53   | 1.4e+06   | 0.72      | 17         | 7.8e-10 | 92      |
- | URI::XSEscape::uri_escape_utf8 | utf36     | 1.48e+06  | 0.674     | 18.4       | 2.1e-10 | 20      |
- | URI::Escape::XS::uri_unescape  | u_ascii53 | 1.6e+06   | 0.61      | 20         | 7e-10   | 44      |
- | URI::Escape::XS::uri_escape    | empty     | 1.63e+06  | 0.612     | 20.3       | 2.1e-10 | 21      |
- | URI::Escape::XS::uri_unescape  | u_ascii66 | 1.83e+06  | 0.548     | 22.7       | 2.1e-10 | 20      |
- | URI::XSEscape::uri_escape_utf8 | empty     | 1.93e+06  | 0.517     | 24         | 2.1e-10 | 21      |
- | URI::XSEscape::uri_unescape    | u_ascii53 | 2.73e+06  | 0.367     | 33.9       | 2e-10   | 24      |
- | URI::XSEscape::uri_unescape    | u_ascii66 | 2.75e+06  | 0.364     | 34.1       | 2.1e-10 | 20      |
- | URI::XSEscape::uri_escape      | ascii53   | 2.88e+06  | 0.348     | 35.7       | 1.9e-10 | 24      |
- | URI::XSEscape::uri_escape      | ascii66   | 3e+06     | 0.34      | 37         | 4e-10   | 345     |
- | URI::XSEscape::uri_escape      | empty     | 5e+06     | 0.2       | 62.1       | 3.5e-11 | 20      |
+ | URI::Encode::uri_decode        | u_ascii53 |      2330 |  429      |       1    | 4.1e-07 |      28 |
+ | URI::Encode::uri_encode        | ascii53   |      2340 |  427      |       1    | 4.3e-07 |      20 |
+ | URI::Encode::uri_encode        | ascii66   |      2410 |  416      |       1.03 | 2.1e-07 |      20 |
+ | URI::Encode::uri_decode        | u_ascii66 |      2410 |  415      |       1.03 | 4.1e-07 |     208 |
+ | URI::Encode::uri_encode        | empty     |      2470 |  404      |       1.06 | 2.1e-07 |      20 |
+ | URI::Escape::uri_escape_utf8   | ascii53   |     82000 |   12.2    |      35.1  | 3.3e-09 |      20 |
+ | URI::Escape::uri_escape        | ascii53   |     85700 |   11.7    |      36.8  | 1.1e-08 |     136 |
+ | URI::Escape::uri_escape_utf8   | utf36     |     96000 |   10      |      41    |   1e-08 |     166 |
+ | URI::Escape::uri_escape_utf8   | ascii66   |    117000 |    8.54   |      50.2  | 3.1e-09 |      23 |
+ | URI::Escape::uri_unescape      | u_ascii53 |    120000 |    8.5    |      50    | 8.6e-09 |     192 |
+ | URI::Escape::uri_escape        | ascii66   |    120000 |    8.1    |      53    | 8.1e-09 |     215 |
+ | URI::Escape::uri_unescape      | u_ascii66 |    180000 |    5.5    |      77    | 5.6e-09 |      28 |
+ | URI::Escape::uri_escape_utf8   | empty     |    900000 |    1.1    |     390    | 1.2e-09 |     155 |
+ | URI::Escape::uri_escape        | empty     |   1310000 |    0.765  |     561    | 7.6e-10 |     150 |
+ | URI::Escape::XS::uri_escape    | ascii66   |   1340000 |    0.748  |     573    | 4.2e-10 |      20 |
+ | URI::Escape::XS::uri_escape    | ascii53   |   1350000 |    0.738  |     581    |   4e-10 |      22 |
+ | URI::XSEscape::uri_escape_utf8 | ascii66   |   1380000 |    0.726  |     590    | 4.1e-10 |      21 |
+ | URI::XSEscape::uri_escape_utf8 | ascii53   |   1400000 |    0.714  |     601    | 3.8e-10 |      25 |
+ | URI::XSEscape::uri_escape_utf8 | utf36     |   1600000 |    0.64   |     670    | 6.9e-10 |     307 |
+ | URI::Escape::XS::uri_unescape  | u_ascii53 |   1600000 |    0.626  |     684    | 6.3e-10 |      20 |
+ | URI::Escape::XS::uri_escape    | empty     |   1670000 |    0.6    |     715    | 2.1e-10 |      20 |
+ | URI::Escape::XS::uri_unescape  | u_ascii66 |   1840000 |    0.542  |     791    | 2.1e-10 |      20 |
+ | URI::XSEscape::uri_escape_utf8 | empty     |   1900000 |    0.52   |     830    |   6e-10 |      22 |
+ | URI::XSEscape::uri_unescape    | u_ascii53 |   2700000 |    0.36   |    1200    | 3.9e-10 |      93 |
+ | URI::XSEscape::uri_escape      | ascii66   |   2820000 |    0.355  |    1210    | 4.5e-11 |      20 |
+ | URI::XSEscape::uri_escape      | ascii53   |   2920000 |    0.343  |    1250    | 1.9e-10 |      26 |
+ | URI::XSEscape::uri_unescape    | u_ascii66 |   2900000 |    0.34   |    1300    | 4.2e-10 |      78 |
+ | URI::Encode::XS::uri_decode    | u_ascii66 |   4700000 |    0.213  |    2020    | 1.1e-10 |      20 |
+ | URI::XSEscape::uri_escape      | empty     |   5400000 |    0.19   |    2300    | 2.6e-10 |      81 |
+ | URI::Encode::XS::uri_decode    | u_ascii53 |   5720000 |    0.175  |    2450    | 4.5e-11 |      20 |
+ | URI::Encode::XS::uri_encode    | ascii66   |   7370000 |    0.136  |    3160    |   1e-10 |      26 |
+ | URI::Encode::XS::uri_encode    | ascii53   |   7850000 |    0.127  |    3370    | 3.9e-11 |      20 |
+ | URI::Encode::XS::uri_encode    | empty     |  13400000 |    0.0745 |    5760    | 6.5e-11 |      20 |
  +--------------------------------+-----------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m URIEscaping --module-startup >>):
 
  +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
+ | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+-----------+------------------------+------------+---------+---------+
- | URI::Escape         | 11.3      | 6.87                   | 1          | 1.1e-05 | 1083    |
- | URI::Escape::XS     | 11        | 6.57                   | 1.03       | 1e-05   | 949     |
- | URI::XSEscape       | 9.38      | 4.95                   | 1.21       | 9.2e-06 | 672     |
- | perl -e1 (baseline) | 4.43      | 0                      | 2.56       | 4.4e-06 | 4009    |
+ | URI::Encode         | 19.2      |                  14.5  | 1          | 1.9e-05 |     723 |
+ | URI::Escape         | 11.6      |                   6.9  | 1.65       | 1.1e-05 |    1557 |
+ | URI::Escape::XS     | 9.26      |                   4.56 | 2.07       | 8.8e-06 |     805 |
+ | URI::XSEscape       | 9.11      |                   4.41 | 2.1        | 8.8e-06 |     596 |
+ | URI::Encode::XS     | 8.2       |                   3.5  | 2.34       | 8.1e-06 |     824 |
+ | perl -e1 (baseline) | 4.7       |                   0    | 4.08       | 4.7e-06 |    5156 |
  +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
